"""
=====================
act.tests (act.tests)
=====================

.. currentmodule:: act.tests

This module contains sample files used for testing the ARM Community Toolkit.
Files in this module should only be used for testing, not production.

.. autosummary::
    :toctree: generated/

    EXAMPLE_SONDE1
    EXAMPLE_LCL1
    EXAMPLE_SONDE_WILDCARD
"""

from .sample_files import (EXAMPLE_SONDE1, EXAMPLE_LCL1,
                           EXAMPLE_SONDE_WILDCARD, EXAMPLE_MET1,
                           EXAMPLE_METE40,
                           EXAMPLE_MET_WILDCARD, EXAMPLE_CEIL1,
                           EXAMPLE_CEIL_WILDCARD, EXAMPLE_ANL_CSV,
                           EXAMPLE_MPL_1SAMPLE, EXAMPLE_IRT25m20s,
                           EXAMPLE_MET_CONTOUR, EXAMPLE_NAV,
                           EXAMPLE_AOSMET, EXAMPLE_DLPPI, EXAMPLE_EBBR1,
                           EXAMPLE_EBBR2, EXAMPLE_BRS, EXAMPLE_AERI,
                           EXAMPLE_MFRSR, EXAMPLE_SURFSPECALB1MLAWER,
                           EXAMPLE_SIGMA_MPLV5)
